@@ -87,6 +87,7 @@ where
             AtRule::Document(n) => emit!(self, n),
             AtRule::ColorProfile(n) => emit!(self, n),
             AtRule::CounterStyle(n) => emit!(self, n),
+            AtRule::Property(n) => emit!(self, n),
             AtRule::Unknown(n) => emit!(self, n),
         }
     }
@@ -873,6 +874,25 @@ where
         punct!(self, "}");
     }
 
+    #[emitter]
+    fn emit_property_rule(&mut self, n: &PropertyRule) -> Result {
+        punct!(self, "@");
+        keyword!(self, "property");
+        space!(self);
+        emit!(self, n.name);
+        formatting_space!(self);
+        punct!(self, "{");
+        self.emit_list(
+            &n.block,
+            if self.config.minify {
+                ListFormat::SemiDelimited
+            } else {
+                ListFormat::SemiDelimited | ListFormat::MultiLine
+            },
+        )?;
+        punct!(self, "}");
+    }
+
     #[emitter]
     fn emit_unknown_at_rule(&mut self, n: &UnknownAtRule) -> Result {
         punct!(self, "@");
